==> snipe-it-5.4.3.zip: snipe-it-5.4.3/resources/lang/es-MX/admin/locations/table.php <==
<?php

return [
    'about_locations_title'     => 'Acerca de ubicaciones',
    'about_locations'           => 'Las Ubicaciones son utilizadas para hacer seguimiento de la información sobre ubicación de usuarios, bienes, y otros items',
    'assets_rtd'                => 'Equipos', // This has NEVER meant Assets Retired. I don't know how it keeps getting reverted.
    'assets_checkedout'         => 'Equipo asignado',
    'id'                        => 'ID',
    'city'                      => 'Ciudad',
    'state'                     => 'Provincia',
    'country'                   => 'Pais',
    'create'                    => 'Crear Localización',
    'update'                    => 'Actualizar Localización',
    'print_assigned'            => 'Imprimir Lo Asignado',
    'print_all_assigned'        => 'Imprimir Lo Asignado',
    'name'                      => 'Nombre Localización',
    'address'                   => 'Dirección',
    'zip'                       => 'Códio Postal',
    'locations'                 => 'Localizaciones',
    'parent'                    => 'Padre',
    'currency'                  => 'Divisa de la Localización',
    'ldap_ou'                   => 'Búsqueda LDAP OU',
    'user_name'                 => 'Nombre de usuario',
    'department'                => 'Departamento',
    'location'                  => 'Localización',
    'asset_tag'                 => 'Etiqueta de Activo',
    'asset_name'                => 'Nombre de Activo',
    'asset_category'            => 'Categoría',
    'asset_manufacturer'        => 'Fabricante',
    'asset_model'               => 'Modelo',
    'asset_serial'              => 'Número de serie',
    'asset_location'            => 'Ubicación',
    'asset_checked_out'         => 'Asignado a',
    'asset_expected_checkin'    => 'Fecha Esperada de Devolución',
    'date'                      => 'Fecha:',
    'signed_by_asset_auditor'   => 'Firmado por (Auditor de Activos):',
    'signed_by_finance_auditor' => 'Firmado por (Auditor de Finanzas):',
    'signed_by_location_manager' => 'Firmado por (Administrador de área):',
    'signed_by'                 => 'Firmado por:',
];

==> snipe-it-6.3.0.zip: snipe-it-6.3.0/resources/lang/es-MX/admin/locations/table.php <==
<?php

return [
    'about_locations_title'     => 'Acerca de ubicaciones',
    'about_locations'           => 'Las Ubicaciones son utilizadas para hacer seguimiento de la información sobre ubicación de usuarios, bienes, y otros items',
    'assets_rtd'                => 'Equipos', // This has NEVER meant Assets Retired. I don't know how it keeps getting reverted.
    'assets_checkedout'         => 'Equipo asignado',
    'id'                        => 'ID',
    'city'                      => 'Ciudad',
    'state'                     => 'Provincia',
    'country'                   => 'Pais',
    'create'                    => 'Crear Localización',
    'update'                    => 'Actualizar Localización',
    'print_assigned'            => 'Imprimir Lo Asignado',
    'print_all_assigned'        => 'Imprimir Lo Asignado',
    'name'                      => 'Nombre Localización',
    'address'                   => 'Dirección',
    'address2'                   => '2da linea de Dirección',
    'zip'                       => 'Códio Postal',
    'locations'                 => 'Localizaciones',
    'parent'                    => 'Padre',
    'currency'                  => 'Divisa de la Localización',
    'ldap_ou'                   => 'Búsqueda LDAP OU',
    'user_name'                 => 'Nombre de usuario',
    'department'                => 'Departamento',
    'location'                  => 'Localización',
    'asset_tag'                 => 'Etiqueta de Activo',
    'asset_name'                => 'Nombre de Activo',
    'asset_category'            => 'Categoría',
    'asset_manufacturer'        => 'Fabricante',
    'asset_model'               => 'Modelo',
    'asset_serial'              => 'Número de serie',
    'asset_location'            => 'Ubicación',
    'asset_checked_out'         => 'Asignado a',
    'asset_expected_checkin'    => 'Fecha Esperada de Devolución',
    'date'                      => 'Fecha:',
    'phone'                     => 'Teléfono ubicación',
    'signed_by_asset_auditor'   => 'Firmado por (Auditor de Activos):',
    'signed_by_finance_auditor' => 'Firmado por (Auditor de Finanzas):',
    'signed_by_location_manager' => 'Firmado por (Administrador de área):',
    'signed_by'                 => 'Firmado por:',
];
